"""
hicon.

Create, use, edit and manage hierarchical configurations files with Python.
"""

__version__ = "0.1.2"
__author__ = "Oscar Nuki"
